@@ -182,7 +182,7 @@ class Endpoint(object):
         if _methods:
             self.client_authn_method = client_auth_setup(_methods, endpoint_context)
         elif _methods is not None:  # [] or '' or something not None but regarded as nothing.
-            pass  # Ignore default value
+            self.client_authn_method = [None]  # Ignore default value
         elif self.default_capabilities:
             _methods = self.default_capabilities.get("client_authn_method")
             if _methods:
